# FEM.edu
A python-based general finite element analysis package for simple testing and developing of finite elements and material models and solution algorithms.

For a detailed documentation visit https://pmackenz.github.io/FEM.edu.documentation/
